@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.8
 ###############################################################################
-# $Id: gdal_create_pdf.py 428d6fbc987332afb0ba6c7b6913390f7386e864 2020-01-17 22:19:28 +0100 Even Rouault $
+# $Id: gdal_create_pdf.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
 #
 #  Project:  GDAL samples
 #  Purpose:  Create a PDF from a XML composition file
@@ -32,10 +32,12 @@ import sys
 
 from osgeo import gdal
 
+
 def Usage():
     print('Usage: gdal_create_pdf composition.xml out.pdf')
     return -1
 
+
 def gdal_create_pdf(argv):
     srcfile = None
     targetfile = None
@@ -64,5 +66,10 @@ def gdal_create_pdf(argv):
         options = ['COMPOSITION_FILE=' + srcfile])
     return 0 if out_ds else 1
 
+
+def main(argv):
+    gdal_create_pdf(argv)
+
+
 if __name__ == '__main__':
-    sys.exit(gdal_create_pdf(sys.argv))
+    sys.exit(main(sys.argv))
