@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.8
 # *****************************************************************************
-# $Id: gdalinfo.py f8fcfbaa4be8da3655f1c12e9dbf535999340e4e 2020-06-03 22:54:27 +0200 Even Rouault $
+# $Id: gdalinfo.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
 #
 # Project:  GDAL Utilities
 # Purpose:  Python port of Commandline application to list info about a file.
@@ -50,12 +50,12 @@ def Usage():
 def EQUAL(a, b):
     return a.lower() == b.lower()
 
-# **********************************************************************
-#                                main()
-# **********************************************************************
-
 
 def main(argv=None):
+    version_num = int(gdal.VersionInfo('VERSION_NUM'))
+    if version_num < 1800:  # because of GetGeoTransform(can_return_null)
+        print('ERROR: Python bindings of GDAL 1.8.0 or later required')
+        return 1
 
     bComputeMinMax = False
     bShowGCPs = True
@@ -607,9 +607,4 @@ def GDALInfoReportCorner(hDataset, hTransform, corner_name, x, y):
 
 
 if __name__ == '__main__':
-    version_num = int(gdal.VersionInfo('VERSION_NUM'))
-    if version_num < 1800:  # because of GetGeoTransform(can_return_null)
-        print('ERROR: Python bindings of GDAL 1.8.0 or later required')
-        sys.exit(1)
-
     sys.exit(main(sys.argv))
